@@ -1,6 +1,9 @@
 # SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
 # SPDX-License-Identifier: MIT
 
+# Note, you must create a feed called "test" in your AdafruitIO account.
+# Your secrets file must contain your aio_username and aio_key
+
 import time
 import board
 import busio
@@ -21,21 +24,34 @@ except ImportError:
     print("WiFi secrets are kept in secrets.py, please add them there!")
     raise
 
+# Debug Level
+# Change the Debug Flag if you have issues with AT commands
+debugflag = False
 
-# With a Particle Argon
-RX = board.ESP_TX
-TX = board.ESP_RX
-resetpin = DigitalInOut(board.ESP_WIFI_EN)
-rtspin = DigitalInOut(board.ESP_CTS)
-uart = busio.UART(TX, RX, timeout=0.1)
-esp_boot = DigitalInOut(board.ESP_BOOT_MODE)
-esp_boot.direction = Direction.OUTPUT
-esp_boot.value = True
-status_light = None
+if board.board_id == "challenger_rp2040_wifi":
+    RX = board.ESP_RX
+    TX = board.ESP_TX
+    resetpin = DigitalInOut(board.WIFI_RESET)
+    rtspin = False
+    uart = busio.UART(TX, RX, baudrate=11520)
+    esp_boot = DigitalInOut(board.WIFI_MODE)
+    esp_boot.direction = Direction.OUTPUT
+    esp_boot.value = True
+    status_light = None
+else:
+    RX = board.ESP_TX
+    TX = board.ESP_RX
+    resetpin = DigitalInOut(board.ESP_WIFI_EN)
+    rtspin = DigitalInOut(board.ESP_CTS)
+    uart = busio.UART(TX, RX, timeout=0.1)
+    esp_boot = DigitalInOut(board.ESP_BOOT_MODE)
+    esp_boot.direction = Direction.OUTPUT
+    esp_boot.value = True
+    status_light = None
 
 print("ESP AT commands")
 esp = adafruit_espatcontrol.ESP_ATcontrol(
-    uart, 115200, reset_pin=resetpin, rts_pin=rtspin, debug=False
+    uart, 115200, reset_pin=resetpin, rts_pin=rtspin, debug=debugflag
 )
 wifi = adafruit_espatcontrol_wifimanager.ESPAT_WiFiManager(esp, secrets, status_light)
 
